# xlcrf

Un tool (libreria Python + script) per creare file utili per la
raccolta dati (con validazione dell'input) a partire da una descrizione
della struttura del dataset desiderato (mediante un file `.xlsx`).

## Utilizzo
Lo strumento si può utilizzare via web [qui](https://share.streamlit.io/lbraglia/webxlcrf/main) oppure da linea di comando, come segue:
```
xlcrf file_struttura.xlsx
```
Questo produrrà `file_struttura_CRF.xlsx`.

## File di struttura

Per indicazioni su come compilarlo segui le istruzioni [qui](https://share.streamlit.io/lbraglia/webxlcrf/main).
